"""
MESH specification model.
"""
from enum import Enum

from bibliograpy.bibliography import PUBMED_FORMAT, PUBMED_PUBLICATION_TYPES, MESH_PUBLICATION_TYPES
from bibliograpy.api_bibtex import _cite


@_cite(PUBMED_FORMAT, PUBMED_PUBLICATION_TYPES, MESH_PUBLICATION_TYPES)
class MeshPublicationType(Enum):
    """Mesh publication types."""

    ABBREVIATIONS = 'Abbreviations'
    """Works consisting of lists of shortened forms of written words or phrases used for brevity. 
    Acronyms are included here."""

    ABSTRACTS = 'Abstracts'
    """Works consisting of lists of publications on a subject and that provide full annotated bibliographical 
    information together with substantive summaries or condensations of the facts, ideas, or opinions presented in each 
    publication listed. (From LC Subject Cataloging Manual)."""

    ACADEMIC_DISSERTATION = 'Academic Dissertation'
    """Work consisting of formal presentations made usually to fulfill requirements for an academic degree."""

    ACCOUNT_BOOK = 'Account Book'
    """Book in which personal or commercial accounts of financial transactions are recorded. 
    (From Random House Unabridged Dictionary, 2d ed)"""

    ADAPTIVE_CLINICAL_TRIAL = 'Adaptive Clinical Trial'
    """Clinical study in which a prospectively planned opportunity is included to modify trial designs and hypotheses 
    based on analysis of data from subjects in the study."""

    ADDRESS = 'Address'
    """Work consisting of speeches, orations, or written statements, usually formal, directed to a particular group of 
    persons. These are different from a LECTURE that is usually delivered to classes for instructional purposes."""

    ADVERTISEMENT = 'Advertisement'
    """Work consisting of publicly distributed notices, usually as paid announcements in mass media such as newspapers, 
    magazines, or on billboards. They include those in motion picture, television advertising, radio, or electronic 
    media. """

    ALMANAC = 'Almanac'
    """Work consisting of a calendar of days, weeks, and months, together with information such as astronomical data, 
    various statistics, etc. 
    (From Genre Terms: A Thesaurus for Use in Rare Book and Special Collections Cataloguing, 2d ed)"""

    ANECDOTES = 'Anecdotes'
    """Works consisting of brief accounts or narratives of incidents or events."""

    ANIMATION = 'Animation'
    """A film or video wholly or partially created by photographing drawings, sculptures, or other inanimate things in 
    sequence to create the illusion of motion. Animations are also generated by computers. 
    (From Moving Image Materials: Genre Terms, 1988)."""

    ANNUAL_REPORT = 'Annual Report'
    """Annual statements concerning the administrative and operational functions of an institution or organization."""

    APHORISMS_AND_PROVERBS = 'Aphorisms and Proverbs'
    """Short memorable sayings in common use. They express in simple language an obvious truth, familiar experience, or 
    advice."""

    ARCHITECTURAL_DRAWING = 'Architectural Drawing'
    """Work consisting of drawings of architecture and architectural projects, whether the project was executed or not. 
    (Art & Architecture Thesaurus, 1990, v.2)."""

    ATLAS = 'Atlas'
    """Work consisting of collections of illustrative plates, charts, etc., usually with explanatory captions."""

    AUTOBIOGRAPHY = 'Autobiography'
    """Self-described narratives of a person's life."""

    BIBLIOGRAPHY = 'Bibliography'
    """A work consisting of a list of books, articles, documents, publications, and other items, usually on a single 
    subject or related subjects."""

    BIOBIBLIOGRAPHY = 'Biobibliography'
    """Works consisting of biographical information as well as lists of the writings of those persons."""

    BIOGRAPHY = 'Biography'
    """Works consisting of an account of the events, works, and achievements, personal and professional, during a 
    person's life."""

    BLOG = 'Blog'
    """A website that contains conversational personal reflections, comments and sometimes links to other sites; 
    typically run by an individual or small group."""

    BOOK_ILLUSTRATIONS = 'Book Illustrations'
    """Works consisting of photographs, prints, drawings, portraits, plates, diagrams, facsimiles, maps, tables, or 
    other representations or systematic arrangements of data designed to elucidate or decorate the contents of a 
    publication. 
    (From The ALA Glossary of Library and Information Science, 1983, p114)."""

    BOOK_REVIEW = 'Book Review'
    """Work consisting of critical analyses of books or other monographic works."""

    BOOKPLATE = 'Bookplate'
    """Works consisting of book owner's identification labels. They are usually intended for attaching inside a book or 
    similar object. (From Thesaurus for Graphic Materials II: Genre and Physical Characteristic Terms, 1995)."""

    BROADSIDE = 'Broadside'
    """Work consisting of published pieces of paper or other material, usually printed on one side and intended to be 
    read unfolded and usually intended to be posted, publicly distributed, or sold, e.g., proclamations, handbills, 
    newssheets, etc. (From Genre Terms: A Thesaurus for Use in Rare Book and Special Collections Cataloguing, 2d ed)."""

    CALENDAR = 'Calendar'
    """Document or chart that shows days, weeks, and months of a year."""

    CARICATURE = 'Caricature'
    """Work portraying in a critical or facetious way a real individual or group, or a figure representing a social, 
    political, ethnic, or racial type. The effect is usually achieved through distortion or exaggeration of 
    characteristics. 
    (Genre Terms: A Thesaurus for Use in Rare Book and Special Collection Cataloguing, 2d ed)."""

    CARTOON = 'Cartoon'
    """Image used to comment on such things as contemporary events, social habits, or political trends; usually 
    executed in a broad or abbreviated manner."""

    CASE_REPORTS = 'Case Reports'
    """Clinical presentations that may be followed by evaluative studies that eventually lead to a diagnosis."""

    CATALOG = 'Catalog'
    """Work consisting of bibliographic records, created according to specific and uniform principles of construction 
    and under the control of an authority file, which describe the materials contained in a collection, library, or 
    group of libraries. Catalogs include also lists of materials prepared for a particular purpose, such as exhibition 
    catalogs, sales catalogs, garden catalogs, medical supply catalogs. 
    (From The ALA Glossary of Library and Information Sciences, 1983)."""

    CATALOG_BOOKSELLER = 'Catalog, Bookseller'
    """Lists of books for sale by a specific seller."""

    CATALOG_COMMERCIAL = 'Catalog, Commercial'
    """Lists of merchandise for sale."""

    CATALOG_DRUG = 'Catalog, Drug'
    """Lists of drugs for sale."""

    CATALOG_PUBLISHER = 'Catalog, Publisher'
    """Lists of books or other titles produced by a specific entity."""

    CATALOG_UNION = 'Catalog, Union'
    """Lists of books and other information sources held among a cooperating group of LIBRARIES."""

    CHART = 'Chart'
    """Work consisting of information presented in graphic form, for example, graphs or diagrams."""

    CHRONOLOGY = 'Chronology'
    """Works consisting of lists of events arranged in chronological order."""

    CLASSICAL_ARTICLE = 'Classical Article'
    """Works consisting of a current presentation of a previously printed seminal article marking a milestone in the 
    history of medicine or science. It is usually accompanied by introductory remarks heralding its reprinting, often 
    on the anniversary of its original publication or on an anniversary of the author's birth or death. It is usually 
    reprinted in full, with complete bibliographical reference to the original appearance."""

    CLINICAL_CONFERENCE = 'Clinical Conference'
    """Work that consists of a conference of physicians on their observations of a patient at the bedside, regarding 
    the physical state, laboratory and other diagnostic findings, clinical manifestations, results of current therapy, 
    etc. A clinical conference usually ends with a confirmation or correction of clinical findings by a pathological 
    diagnosis performed by a pathologist. "Clinical conference" is often referred to as a "clinico-pathological 
    conference."
    """

    CLINICAL_STUDY = 'Clinical Study'
    """A work that reports on the results of a research study to evaluate interventions or exposures on biomedical or 
    health-related outcomes.  The two main types of clinical studies are interventional studies (clinical trials) and 
    observational studies. While most clinical studies concern humans, this publication type may be used for clinical 
    veterinary articles meeting the requisites for humans."""

    CLINICAL_TRIAL = 'Clinical Trial'
    """A work that reports on the results of a clinical study in which participants are assigned to receive one or more 
    interventions so that researchers can evaluate the interventions on biomedical or health-related outcomes. The 
    assignments are determined by the study protocol. Participants may receive diagnostic, therapeutic, or other types 
    of interventions. For clinical trials on  veterinary animals see CLINICAL TRIAL, VETERINARY. Clinical Trials was 
    used for both humans and non-humans prior to 2019."""

    CLINICAL_TRIAL_PROTOCOL  = 'Clinical Trial Protocol'
    """The written description of a clinical study. It contains the study's objectives, design, and methods including 
    subject target and/or enrollment criteria. It may also present relevant scientific background and statistical 
    information."""

    CLINICAL_TRIAL_PHASE_I = 'Clinical Trial, Phase I'
    """Work that is the report of a pre-planned, usually controlled, clinical study of the safety and efficacy of 
    diagnostic, therapeutic, or prophylactic drugs, devices, or techniques based on a small number of healthy persons 
    and conducted over the period of about a year in either the United States or a foreign country."""

    CLINICAL_TRIAL_PHASE_II = 'Clinical Trial, Phase II'
    """Work that is a report of a pre-planned, usually controlled, clinical study of the safety and efficacy of 
    diagnostic, therapeutic, or prophylactic drugs, devices, or techniques based on several hundred volunteers, 
    including a limited number of patients, and conducted over a period of about two years in either the United States 
    or a foreign country."""

    CLINICAL_TRIAL_PHASE_III = 'Clinical Trial, Phase III'
    """Work that is a report of a pre-planned, usually controlled, clinical study of the safety and efficacy of 
    diagnostic, therapeutic, or prophylactic drugs, devices, or techniques after phase II trials. A large enough group 
    of patients is studied and closely monitored by physicians for adverse response to long-term exposure, over a 
    period of about three years in either the United States or a foreign country."""

    CLINICAL_TRIAL_PHASE_IV = 'Clinical Trial, Phase IV'
    """Work that is a report of a planned post-marketing study of diagnostic, therapeutic, or prophylactic drugs, 
    devices, or techniques that have been approved for general sale after clinical trials, phases I, II, and III. These 
    studies, conducted in the United States or a foreign country, often garner additional data about the safety and 
    efficacy of a product."""

    CLINICAL_TRIAL_VETERINARY = 'Clinical Trial, Veterinary'
    """A work that is a veterinary clinical study in which animal participants are assigned to receive one or more 
    interventions so that researchers can evaluate the interventions on biomedical or health-related outcomes. The 
    assignments are determined by the study protocol. Animal participants may receive diagnostic, therapeutic, or other 
    types of interventions."""

    COLLECTED_CORRESPONDENCE = 'Collected Correspondence'
    """Written communication between persons or between institutions or organizations."""

    COLLECTED_WORK = 'Collected Work'
    """Work consisting of collections of previously published works."""

    COLLECTION = 'Collection'
    """Items gathered and assembled in some order to facilitate access or use."""

    COMMENT = 'Comment'
    """Work consisting of a critical or explanatory note written to discuss, support, or dispute an article or other 
    presentation previously published. It may take the form of an article, letter, editorial, etc. It appears in 
    publications under a variety of names: comment, commentary, editorial comment, viewpoint, etc."""

    COMPARATIVE_STUDY = 'Comparative Study'
    """Comparison of outcomes, results, responses, etc for different techniques, therapeutic approaches or other inputs.
    """

    CONGRESS = 'Congress'
    """Published record of the papers delivered at or issued on the occasion of individual congresses, symposia, and 
    meetings; abstracts of papers delivered at such congresses; reports of the officers and delegates of such 
    congresses; combinations of the foregoing; or proceedings of the conference of a society if they are not limited to 
    matters of internal organization."""

    CONSENSUS_DEVELOPMENT_CONFERENCE = 'Consensus Development Conference'
    """Official statements of the findings or recommendations expressing the outcome of a meeting convened to evaluate 
    current thought and research on a subject of interest."""

    CONSENSUS_DEVELOPMENT_CONFERENCE_NIH = 'Consensus Development Conference, NIH'
    """Official statements of the finding or recommendations expressing the outcome from a conference sponsored by NIH.
    """

    CONTROLLED_CLINICAL_TRIAL = 'Controlled Clinical Trial'
    """A work that reports on a clinical trial involving one or more test treatments, at least one control treatment, 
    specified outcome measures for evaluating the studied intervention, and a bias-free method for assigning patients 
    to the test treatment. The treatment may be drugs, devices, or procedures studied for diagnostic, therapeutic, or 
    prophylactic effectiveness. Control measures include placebos, active medicine, no-treatment, dosage forms and 
    regimens, historical comparisons, etc. When randomization using mathematical techniques, such as the use of a 
    random numbers table, is employed to assign patients to test or control treatments, the trial is characterized as a 
    RANDOMIZED CONTROLLED TRIAL."""

    COOKBOOK = 'Cookbook'
    """Collection of recipes or instructions for preparation of food and organization of meals."""

    CORRECTED_AND_REPUBLISHED_ARTICLE = 'Corrected and Republished Article'
    """Work that is the republication of an article to correct, amplify, or restore text and data of the originally 
    published article."""

    DATABASE = 'Database'
    """A structured file of information or a set of logically related data stored and retrieved using computer-based 
    means."""

    DATASET = 'Dataset'
    """Works consisting of organized collections of data, which have been stored permanently in a formalized manner 
    suitable for communication, interpretation, or processing."""

    DIARY = 'Diary'
    """Work consisting of records, usually private, of writers' experiences, observations, feelings, attitudes, etc. 
    They may also be works marked in calendar order in which to note appointments and the like. 
    (From Random House Unabridged Dictionary, 2d ed)."""

    DICTIONARY = 'Dictionary'
    """A reference book containing a list of words - usually in alphabetical order - giving information about form, 
    pronunciation, etymology, grammar, and meaning. A foreign-language dictionary is an alphabetical list of words of 
    one language with their meaning and equivalents in another language."""

    DICTIONARY_CHEMICAL = 'Dictionary, Chemical'
    """A reference book containing a list of words related to chemistry-usually in alphabetic order-giving information 
    about form, pronunciation, etymology, grammar, and meaning."""

    DICTIONARY_CLASSICAL = 'Dictionary, Classical'
    """A reference work containing a list of words related to the Greco-Roman World giving information about form, 
    pronunciation, etymology, grammar, and meaning."""

    DICTIONARY_DENTAL = 'Dictionary, Dental'
    """A reference book containing a list of words related to dentistry-usually in alphabetic order-giving information 
    about form, pronunciation, etymology, grammar, and meaning."""

    DICTIONARY_MEDICAL = 'Dictionary, Medical'
    """A reference book containing a list of words related to medicine-usually in alphabetic order-giving information 
    about form, pronunciation, etymology, grammar, and meaning."""

    DICTIONARY_PHARMACEUTIC = 'Dictionary, Pharmaceutic'
    """A reference book containing a list of words related to pharmacy-usually in alphabetic order-giving information 
    about form, pronunciation, etymology, grammar, and meaning."""

    DICTIONARY_POLYGLOT = 'Dictionary, Polyglot'
    """Reference list of definitions of words repeated in several languages."""

    DIRECTORY = 'Directory'
    """Work consisting of an alphabetical or classified list of names, organizations, subjects, etc., giving usually 
    titles, addresses, affiliations, and other professional data."""

    DISPENSATORY = 'Dispensatory'
    """Systematic description of the drugs and preparations used generally or in a specific setting."""

    DOCUMENTARIES_AND_FACTUAL_FILMS = 'Documentaries and Factual Films'
    """Works consisting of films, videos, and programs which depict actual persons or actual events. They do not 
    include frank historical re-creations and do not attempt to judge the truth of the depiction in a film purporting 
    to be factual or documentary in character. (From Moving Image Materials: Genre Terms, 1988)."""

    DRAWING = 'Drawing'
    """Work consisting of graphic representations of objects or ideas by lines."""

    DUPLICATE_PUBLICATION = 'Duplicate Publication'
    """Work consisting of an article or book of identical or nearly identical material published simultaneously or 
    successively to material previously published elsewhere, without acknowledgment of the prior publication."""

    EDITORIAL = 'Editorial'
    """Work consisting of a statement of the opinions, beliefs, and policy of the editor or publisher of a journal, 
    usually on current matters of medical or scientific significance to the medical community or society at large. The 
    editorials published by editors of journals representing the official organ of a society or organization are 
    generally substantive."""

    ELECTRONIC_SUPPLEMENTARY_MATERIALS = 'Electronic Supplementary Materials'
    """Supporting content or information, such as animation, datasets, multimedia files, video, movies, audio files, 
    text files, or software, which is submitted for publication in an online journal or an online edition of a journal. 
    This information may be referenced in the text of the article with a link to the supplementary data provided. 
    CATALOG: do not use."""

    ENCYCLOPEDIA = 'Encyclopedia'
    """Work containing informational articles on subjects in every field of knowledge, usually arranged in alphabetical 
    order, or a similar work limited to a special field or subject."""

    ENGLISH_ABSTRACT = 'English Abstract'
    """Identifier for English language abstracts provided with non-English language works."""

    EPHEMERA = 'Ephemera'
    """Works consisting of transient everyday items, usually printed on paper, that are produced for a specific limited 
    use and then often thrown away. (From Genre Terms: A Thesaurus for Use in Rare Book and Special Collections 
    Cataloguing, 2d ed & The ALA Glossary of Library and Information Science, 1983)."""

    EQUIVALENCE_TRIAL = 'Equivalence Trial'
    """Trial that aims to show a new treatment is no better and no worse than the standard treatment."""

    ESSAY = 'Essay'
    """Short literary prose composition, usually dealing with a single theme."""

    EULOGY = 'Eulogy'
    """Work consisting of speeches or writings in praise of a person or thing, especially a set oration in honor of a 
    deceased person. They differ from FUNERAL SERMON which are delivered at ceremonies for the deceased prior to their 
    burial or cremation. (From Random House Unabridged Dictionary, 2d ed)."""

    EVALUATION_STUDY = 'Evaluation Study'
    """Works consisting of studies determining the effectiveness or utility of processes, personnel, and equipment."""

    EXAMINATION_QUESTIONS = 'Examination Questions'
    """Work consisting of compilations of questions and answers pertaining to a particular subject, used for study and 
    review."""

    EXHIBITION = 'Exhibition'
    """Objects publicly displayed."""

    EXPRESSION_OF_CONCERN = 'Expression of Concern'
    """A notification about the integrity of a published article that is typically written by an editor and should be 
    labelled prominently in the item title. It is the responsibility of the editor to initiate appropriate 
    investigative procedures, discover the outcome of the investigation, and notify readers of that outcome in a 
    subsequent published item. The outcome may require the publication of a retraction notice."""

    FESTSCHRIFT = 'Festschrift'
    """Work consisting of a collection of essays or other writings contributed by students, teachers, colleagues, and 
    associates to honor a person or institution, usually on the occasion of an anniversary celebration or other event 
    of importance."""

    FICTIONAL_WORK = 'Fictional Work'
    """Work consisting of creative writing, not presented as factual."""

    FORM = 'Form'
    """Document used for acquiring particular information or for presenting particular information in a prescribed 
    sequence and format, often with blank spaces or lines or other methods to prompt for insertion of the requested 
    information."""

    FORMULARY = 'Formulary'
    """Work that consists of lists of drugs or collections of recipes, formulas, and prescriptions for the compounding 
    of medicinal preparations."""

    FORMULARY_DENTAL = 'Formulary, Dental'
    """Works on or about reference lists of descriptions and uses of drugs related to oral medicine and dentistry."""

    FORMULARY_HOMEOPATHIC = 'Formulary, Homeopathic'
    """Work about Formulary concerned with HOMEOPATHIC REMEDIES."""

    FORMULARY_HOSPITAL = 'Formulary, Hospital'
    """Formulary concerned with PHARMACEUTICAL PREPARATIONS prescribed in hospitals."""

    FUNERAL_SERMON = 'Funeral Sermon'
    """Work consisting of sermons delivered at ceremonies for a dead person prior to burial or cremation. 
    (From Random House Unabridged Dictionary, 2d ed)."""

    GOVERNMENT_PUBLICATION = 'Government Publication'
    """Work consisting of publications issued by local, regional, or national governments or by their agencies or 
    subdivisions."""

    GRAPHIC_NOVEL = 'Graphic Novel'
    """Book-length narratives told using a combination of words and sequential art, often presented in comic book 
    style. from (Fletcher-Spear et al., ALA Review, Winter 2005)."""

    GUIDEBOOK = 'Guidebook'
    """Work consisting of publications for travelers that give information about a city, region, or country, or similar 
    handbooks about buildings, museums, etc. (The ALA Glossary of Library and Information Science, 1983)."""

    GUIDELINE = 'Guideline'
    """Work consisting of a set of statements, directions, or principles presenting current or future rules or policy. 
    Guidelines may be developed by government agencies at any level, institutions, organizations such as professional 
    societies or governing boards, or by the convening of expert panels. The text may be cursive or in outline form, 
    but it is generally a comprehensive guide to problems and approaches in any discipline or activity. This concept 
    relates to the general conduct and administration of health care activities rather than to specific decisions for a 
    particular clinical condition. For that aspect, PRACTICE GUIDELINE is available."""

    HANDBOOK = 'Handbook'
    """Work consisting of concise reference works in which facts and information pertaining to a certain subject or 
    field are arranged for ready reference and consultation rather than for continuous reading and study."""

    HERBAL = 'Herbal'
    """Work such as books on herbs or plants usually describing their medicinal value. 
    (Random House Unabridged Dictionary, 2d ed)."""

    HISTORICAL_ARTICLE = 'Historical Article'
    """An article or portion of an article giving an account of past events or circumstances significant in a field of 
    study, a profession, a discovery, an invention, etc. The concept of history is very wide, ranging from the dawn of 
    time to the present. This publication type is often checked in conjunction with BIOGRAPHY."""

    INCUNABULA = 'Incunabula'
    """Books printed before 1501."""

    INDEX = 'Index'
    """Work providing an analytical subject approach to materials in a field of knowledge."""

    INSTRUCTIONAL_FILM_AND_VIDEO = 'Instructional Film and Video'
    """Works consisting of nonfiction films and video designed to teach, instruct, or train. 
    (From Moving Image Materials: Genre Terms, 1988)."""

    INTERACTIVE_TUTORIAL = 'Interactive Tutorial'
    """Video recordings or other files in which the progress of the instruction or content is determined by user 
    response."""

    INTERVIEW = 'Interview'
    """Work consisting of a conversation with an individual regarding his or her background and other personal and 
    professional details, opinions on specific subjects posed by the interviewer, etc."""

    INTRODUCTORY_JOURNAL_ARTICLE = 'Introductory Journal Article'
    """Prefatory summary to a special issue or section of a journal devoted to a specific topic. This introductory text 
    can be of varying length and substance."""

    JOURNAL_ARTICLE = 'Journal Article'
    """The predominant publication type for articles and other items indexed for NLM databases."""

    JUVENILE_LITERATURE = 'Juvenile Literature'
    """Works produced for children through age 15 or through the ninth grade."""

    LABORATORY_MANUAL = 'Laboratory Manual'
    """Work containing concise background information and directions for activities, including conducting experiments 
    or diagnostic tests in the laboratory."""

    LECTURE = 'Lecture'
    """Work consisting of speeches read or delivered before an audience or class, especially for instruction or to set 
    forth some subject. They are differentiated from an ADDRESS which are less didactic and more informational, 
    entertaining, inspirational, or polemic. (From Random House Unabridged Dictionary, 2d ed)."""

    LECTURE_NOTE = 'Lecture Note'
    """Work consisting of notes taken at the delivery or reading of a speech before an audience or class, usually given 
    to instruct. (From Random House Unabridged Dictionary, 2d ed)."""

    LEGAL_CASE = 'Legal Case'
    """Work consisting of collections of law reports or the published reports of decided cases and documents or filings 
    related to those cases."""

    LEGISLATION = 'Legislation'
    """Works consisting of the text of proposed or enacted legislation that may be in the form of bills, laws, 
    statutes, ordinances, or government regulations."""

    LETTER = 'Letter'
    """Work consisting of written or printed communication between individuals or between persons and representatives 
    of corporate bodies. The correspondence may be personal or professional. In medical and other scientific 
    publications the letter is usually from one or more authors to the editor of the journal or book publishing the 
    item being commented upon or discussed. LETTER is often accompanied by COMMENT."""

    MANUSCRIPT = 'Manuscript'
    """Work written by hand, as one written before the invention or adoption of printing."""

    MANUSCRIPT_MEDICAL = 'Manuscript, Medical'
    """Medical works prepared by hand including handwritten or typescript drafts of pre-publication papers or works not 
    otherwise reproduced in multiple copies."""

    MAP = 'Map'
    """Works consisting of representations, normally to scale and on a flat medium, of a selection of material or 
    abstract features on the surface of the earth. They may be used also in delineating the heavens and celestial 
    bodies. (From Anglo-American Cataloguing Rules, 2d ed, p619."""

    MEETING_ABSTRACT = 'Meeting Abstract'
    """Individual abstracts of presentations at meetings, congresses, conferences, symposia, colloquia, seminars, 
    workshops, round tables, and other professional gatherings."""

    META_ANALYSIS = 'Meta-Analysis'
    """Works consisting of studies using a quantitative method of combining the results of independent studies 
    (usually drawn from the published literature) and synthesizing summaries and conclusions which may be used to 
    evaluate therapeutic effectiveness, plan new studies, etc. It is often an overview of clinical trials. It is 
    usually called a meta-analysis by the author or sponsoring body and should be differentiated from reviews of 
    literature."""

    MONOGRAPH = 'Monograph'
    """Work that is any publication that is not a serial or integrating resource. In cataloging usage, It is usually on 
    a single subject or related subjects and is complete in itself, whether constructed of chapters, sections, or 
    parts. While any article encountered in indexing journals can be, strictly speaking, a monograph, as a publication 
    type, a monograph will refer to a cataloging. item."""

    MOVABLE_BOOKS = 'Movable Books'
    """Books having mechanisms or parts that move, or are moved by the reader."""

    MULTICENTER_STUDY = 'Multicenter Study'
    """A work that reports on a study executed by several cooperating institutions."""

    NEWS = 'News'
    """Works consisting of an announcement or statement of recent or current events of new data and matters of interest 
    in the field of medicine or science. In some publications, such as "Nature" or "Science," the news reports are 
    substantively written and herald medical and scientific data of vital or controversial importance."""

    NEWSPAPER_ARTICLE = 'Newspaper Article'
    """Work consisting of a news item appearing in a general-interest newspaper or other general news periodical, 
    containing information of current and timely interest in the field of medicine or science. This publication type 
    should not be confused with NEWS Publication Type, reserved for news reports published in various medical or other 
    scientific journals, such as "Nature".)"""

    NURSES_INSTRUCTION = 'Nurses Instruction'
    """Work consisting of materials developed for a nursing audience."""

    OBSERVATIONAL_STUDY = 'Observational Study'
    """A work that reports on the results of a clinical study in which participants may receive diagnostic, 
    therapeutic, or other types of interventions, but the investigator does not assign participants to specific 
    interventions (as in an interventional study)."""

    OBSERVATIONAL_STUDY_VETERINARY = 'Observational Study, Veterinary'
    """Reports on studies of the results of a clinical study in which animal subjects may receive diagnostic, 
    therapeutic, or other types of interventions, where the investigator does not assign participants to specific 
    interventions."""

    OUTLINE = 'Outline'
    """Work consisting of brief statements of the principal elements of a subject, usually arranged by heads and 
    subheads."""

    OVERALL = 'Overall'
    """A single citation covering papers or abstracts presented at a meeting. The publication type may be used for a 
    single citation with or without the additional indexing or cataloging of individual papers. The individual papers, 
    however, are not labeled OVERALL."""

    PATENT = 'Patent'
    """Work consisting of documents granted by a government giving exclusive rights to an inventor or assignee to 
    manufacture, use, or sell an invention for a certain number of years."""

    PATIENT_EDUCATION_HANDOUT = 'Patient Education Handout'
    """Works consisting of a handout or self-contained informative material used to explain a procedure or a condition 
    or the contents of a specific article in a biomedical journal and written in non-technical language for the patient 
    or consumer."""

    PERIODICAL = 'Periodical'
    """Publication intended to be issued on an ongoing basis, generally more frequently than annually, containing 
    separate articles, stories, or writings."""

    PERIODICAL_INDEX = 'Periodical Index'
    """Work consisting of a subject approach to the contents of a periodical issuing an annual, biennial, quinquennial, 
    decennial, etc., index. The heading is used for the overall body of articles published by a periodical in the same 
    sense that BIBLIOGRAPHY is useful when published as a single article."""

    PERSONAL_NARRATIVE = 'Personal Narrative'
    """Work consisting of accounts of individual experience in relation to a particular field or of participation in 
    related activities."""

    PHARMACOPOEIA = 'Pharmacopoeia'
    """Authoritative work containing lists of drugs and preparations, their description, formulation, analytic 
    composition, main chemical properties, standards for strength, purity, and dosage, chemical tests for determining 
    identity, etc. They have the status of a standard."""

    PHARMACOPOEIA_HOMEOPATHIC = 'Pharmacopoeia, Homeopathic'
    """Authoritative resource describing the composition, properties, manufacture, and quality control of HOMEOPATHIC 
    REMEDIES."""

    PHOTOGRAPH = 'Photograph'
    """Still image produced from radiation-sensitive materials (sensitive to light, electron beams, or nuclear 
    radiation), generally by means of the chemical action of light on a sensitive film, paper, glass, or metal. 
    Photographs may be positive or negative, opaque or transparent."""

    PHRASES  = 'Phrases'
    """Work consisting of common terms, phrases, idioms, and typical conversations, e.g., between health professional 
    and patients. These are often intended for use by non-native speakers of a language."""

    PICTORIAL_WORK = 'Pictorial Work'
    """Work consisting exclusively or mainly of pictures but not technical drawings."""

    POETRY = 'Poetry'
    """Works that consist of literary and oral genre expressing meaning via symbolism and following formal or informal 
    patterns."""

    POPULAR_WORK = 'Popular Work'
    """Work written for non-professional or lay audiences."""

    PORTRAIT = 'Portrait'
    """Work consisting of graphic representations, especially of the face, of real persons, usually posed, living or 
    dead. They are pictures whose purpose is the portrayal of an individual or group of individuals, not pictures which 
    merely include people as part of an event or scene. (From Thesaurus for Graphic Materials II, p540, 1995)."""

    POSTCARD = 'Postcard'
    """Card on which a message may be written or printed for mailing without an envelope. Art & Architectural Thesaurus 
    Online www.getty.edu/research/conducting_research/vocabularies/aat/ accessed 12/18/2008"""

    POSTER = 'Poster'
    """Work consisting of single or multi-sheet notices made to attract attention to events, activities, causes, goods, 
    or services. They are for posting, usually in a public place and are chiefly pictorial. They are intended to make 
    an immediate impression from a distance. Posters do not include poster presentations at conferences and meetings. 
    (From Thesaurus for Graphic Materials II: Genre and Physical Characteristic Headings, 1995)."""

    PRACTICE_GUIDELINE = 'Practice Guideline'
    """Work consisting of a set of directions or principles to assist the health care practitioner with patient care 
    decisions about appropriate diagnostic, therapeutic, or other clinical procedures for specific clinical 
    circumstances. Practice guidelines may be developed by government agencies at any level, institutions, 
    organizations such as professional societies or governing boards, or by the convening of expert panels. They can 
    provide a foundation for assessing and evaluating the quality and effectiveness of health care in terms of 
    measuring improved health, reduction of variation in services or procedures performed, and reduction of variation 
    in outcomes of health care delivered."""

    PRAGMATIC_CLINICAL_TRIAL = 'Pragmatic Clinical Trial'
    """Randomized clinical trials that compare interventions in clinical settings and which look at a range of 
    effectiveness outcomes and impacts."""

    PREPRINT = 'Preprint'
    """Scientific manuscript made available prior to PEER REVIEW."""

    PRICE_LIST = 'Price List'
    """Work consisting of lists giving the prices of items for sale, including drugs, equipment, books, etc. Price 
    lists are less detailed than catalogs and not as long."""

    PROBLEMS_AND_EXERCISES = 'Problems and Exercises'
    """Works consisting of collections of practice questions and drills, generally for instructional or review use."""

    PROGRAM = 'Program'
    """Works consisting of lists of the events, pieces, performers, speakers, etc., of an entertainment, ceremony, or 
    the like. (From: Genre Terms: A Thesaurus for Use in Rare Book and Special Collections Cataloging, 2d ed)."""

    PROGRAMMED_INSTRUCTION = 'Programmed Instruction'
    """Works consisting of sequenced self-correction texts."""

    PROSPECTUS = 'Prospectus'
    """Work consisting of advertisements separately printed and distributed by a publisher to describe and solicit 
    orders for a recent or forthcoming publication. In the case of books, they may include sample pages. 
    (From: ALA Glossary of Library and Information Science, 1983)."""

    PUBLIC_SERVICE_ANNOUNCEMENT = 'Public Service Announcement'
    """Work consisting of announcements which promote programs, activities, or services of federal, state, or local 
    governments or those of non-profit organizations and other announcements regarded as serving community interests.
    """

    PUBLICATION_COMPONENTS = 'Publication Components'
    """Specific parts of publications."""

    PUBLICATION_FORMATS = 'Publication Formats'
    """Specific genre of publication."""

    PUBLISHED_ERRATUM = 'Published Erratum'
    """Work consisting of an acknowledgment of an error, issued by a publisher, editor, or author. It customarily cites 
    the source where the error occurred, giving complete bibliographic data for retrieval. In the case of books and 
    monographs, author, title, imprint, paging, and other helpful references will be given; in the case of journal 
    articles, the author, title, paging, and journal reference will be shown. An erratum notice is variously cited as 
    Errata or Corrigenda."""

    RANDOMIZED_CONTROLLED_TRIAL = 'Randomized Controlled Trial'
    """A work that reports on a clinical trial that involves at least one test treatment and one control treatment, 
    concurrent enrollment and follow-up of the test- and control-treated groups, and in which the treatments to be 
    administered are selected by a random process, such as the use of a random-numbers table."""

    RANDOMIZED_CONTROLLED_TRIAL_VETERINARY = 'Randomized Controlled Trial, Veterinary'
    """A work that reports on a clinical trial with animal subjects that involves at least one test treatment and one 
    control treatment, concurrent enrollment and follow-up of the test- and control-treated groups, and in which the 
    treatments to be administered are selected by a random process, such as the use of a random-numbers table."""

    RESEARCH_SUPPORT_AMERICAN_RECOVERY_AND_REINVESTMENT_ACT = 'Research Support, American Recovery and Reinvestment Act'
    """Acknowledgement that funding support is from the American Recovery and Reinvestment Act."""

    RESEARCH_SUPPORT_NIH_EXTRAMURAL = 'Research Support, N.I.H., Extramural'
    """A designation for publications of research resulting from extramural research funded by the National Institutes 
    of Health."""

    RESEARCH_SUPPORT_NIH_INTRAMURAL = 'Research Support, N.I.H., Intramural'
    """A designation for publications of research resulting from intramural research at the National Institutes of 
    Health."""

    RESEARCH_SUPPORT_NON_US_GOVT = "Research Support, Non-U.S. Gov't"
    """Acknowledgement that funding support is from any non-US government agency, for example state and local 
    governments, foreign governments, and private organizations."""

    RESEARCH_SUPPORT_US_GOVT_NON_PHS = "Research Support, U.S. Gov't, Non-P.H.S."
    """Acknowledgment that funding support is from any US government agency other than the Public Health Service, such 
    as the National Science Foundation, NASA, Department of Energy, etc."""

    RESEARCH_SUPPORT_US_GOVT_PHS = "Research Support, U.S. Gov't, P.H.S."
    """Acknowledgement that funding support is from any component of the Public Health Service."""

    RESEARCH_SUPPORT_US_GOVERNMENT = 'Research Support, U.S. Government'
    """For publications noted as supported by US Government."""

    RESOURCE_GUIDE = 'Resource Guide'
    """Work listing and describing various sources of information, from multiple media or in different formats, on a 
    given subject."""

    RETRACTED_PUBLICATION = 'Retracted Publication'
    """Work consisting of the designation of an article or book as retracted in whole or in part by an author or 
    authors or an authorized representative. It identifies a citation previously published and now retracted through a 
    formal issuance from the author, publisher, or other authorized agent, and is distinguished from RETRACTION OF 
    PUBLICATION, which identifies the citation retracting the original published item."""

    RETRACTION_OF_PUBLICATION = 'Retraction of Publication'
    """Work consisting of a statement issued by one or more authors of an article or a book, withdrawing or disavowing 
    acknowledgment of their participation in performing research or writing the results of their study. In indexing, 
    the retraction is sent to the editor of the publication in which the article appeared and is published under the 
    rubric "retraction" or in the form of a letter. This publication type designates the author's statement of 
    retraction: it should be differentiated from RETRACTED PUBLICATION which labels the retracted publication."""

    REVIEW = 'Review'
    """An article or book published after examination of published material on a subject. It may be comprehensive to 
    various degrees and the time range of material scrutinized may be broad or narrow, but the reviews most often 
    desired are reviews of the current literature. The textual material examined may be equally broad and can 
    encompass, in medicine specifically, clinical material as well as experimental research or case reports. 
    State-of-the-art reviews tend to address more current matters. A review of the literature must be differentiated 
    from HISTORICAL ARTICLE on the same subject, but a review of historical literature is also within the scope of this 
    publication type."""

    SCIENTIFIC_INTEGRITY_REVIEW = 'Scientific Integrity Review'
    """Work consisting of reports by the United States Office of Research Integrity, identifying questionable research 
    published in articles or books. Notification of the questionable data is carried in the NIH Guide for Grants and 
    Contracts."""

    SERMON = 'Sermon'
    """Work consisting of discourses for the purpose of religious instruction or exhortation, especially one based on a 
    text of Scripture and delivered by a member of the clergy, as part of a religious service. (From: Random House 
    Unabridged Dictionary, 2d ed)."""

    STATISTICS = 'Statistics'
    """Works consisting of presentations of numerical data on particular subjects."""

    STURY_CHARACTERISTICS = 'Study Characteristics'
    """Type of empirical method used."""

    STUEY_GUIDE = 'Study Guide'
    """Tool used to help facilitate learning and comprehension of a topic or to help prepare for an examination."""

    SUPPORT_OF_RESEARCH = 'Support of Research'
    """Organizational source for funding of research activity."""

    SYSTEMATIC_REVIEW = 'Systematic Review'
    """A review of primary literature in health and health policy that attempts to identify, appraise, and synthesize 
    all the empirical evidence that meets specified eligibility criteria to answer a given research question.  Its 
    conduct uses explicit methods aimed at minimizing bias in order to produce more reliable findings regarding the 
    effects of interventions for prevention, treatment, and rehabilitation that can be used to inform decision making.
    """

    TABLES = 'Tables'
    """Presentations of data in tabular form."""

    TECHNICAL_REPORT = 'Technical Report'
    """Work consisting of a formal report giving details of the investigation and results of a medical or other 
    scientific problem. When issued by a government agency or comparable official body, its contents may be classified, 
    unclassified, or declassified with regard to security clearance. This publication type may also cover a scientific 
    paper or article that records the current state or current position of scientific research and development. If so 
    labeled by the editor or publisher, this publication type may be properly used for journal articles."""

    TERMINOLOGY = 'Terminology'
    """Work consisting of lists of the technical terms or expressions used in a specific field. These lists may or may 
    not be formally adopted or sanctioned by usage."""

    TEXTBOOK = 'Textbook'
    """Book intended for use in the study of specific subjects, containing systematic presentation of the principles 
    and essential knowledge of the subjects."""

    TWIN_STUDY = 'Twin Study'
    """Work consisting of reporting using a method of detecting genetic causes in human traits and genetic factors in 
    behavior using sets of twins."""

    UNEDITED_FOOTAGE = 'Unedited Footage'
    """Work consisting of untitled raw motion picture and video footage which has not been edited or assembled into a 
    finished work. (From: Moving Image Materials: Genre Terms, 1988)"""

    UNION_LIST = 'Union List'
    """Works consisting of records of the holdings or items owned by two or more libraries."""

    UNPUBLISHED_WORK = 'Unpublished Work'
    """Work that has not been formally published."""

    VALIDATION_STUDY = 'Validation Study'
    """Works consisting of research using processes by which the reliability and relevance of a procedure for a 
    specific purpose are established"""

    VIDEO_AUDIO_MEDIA = 'Video-Audio Media'
    """Used with articles which include video files or clips, or for articles which are entirely video."""

    WEB_ARCHIVE  = 'Web Archive'
    """Collection of preserved web pages."""

    WEBCAST = 'Webcast'
    """Content from transmission of live or pre-recorded audio or video via connection or download from the INTERNET."""

    WIT_AND_HUMOR = 'Wit and Humor'

    @staticmethod
    def parse(entry_type: str | list[str]):
        """Parses an entry type name into an enum value."""
        if isinstance(entry_type, list):
            return [MeshPublicationType.parse(v) for v in entry_type]
        for n in MeshPublicationType:
            if entry_type == n.value:
                return n
        raise ValueError(f'unknown {entry_type} type')
